# How about no

![tests][tests]
![black][black]
![pylint][pylint]
![isort][isort]

![how_about_no][how_about_no]

*Image source: https://knowyourmeme.com/photos/129577-how-about-no*

The sole purpose of this library is to let your CI/CD tool know whether or not the
build it's about to run is necessary.

Please note that there is no stable release yet, and the documentation will be added
shortly.



[tests]: https://github.com/mateuszcisek/how_about_no/actions/workflows/tests.yaml/badge.svg "tests"
[black]: https://github.com/mateuszcisek/how_about_no/actions/workflows/linting_black.yaml/badge.svg "black"
[pylint]: https://github.com/mateuszcisek/how_about_no/actions/workflows/linting_pylint.yaml/badge.svg "pylint"
[isort]: https://github.com/mateuszcisek/how_about_no/actions/workflows/linting_isort.yaml/badge.svg "isort"
[how_about_no]: how_about_no.jpg "how about no"
